@@ -8,7 +8,7 @@ from revauth.serializers import ProfileJWTSerializer
 from django.db.utils import IntegrityError
 import requests
 from django.conf import settings
-from jwt import decode, get_unverified_header
+from revjwt import decode
 
 
 class BaseHandler:
@@ -46,9 +46,7 @@ class BaseHandler:
     def perform_register(self, **kwargs):
         try:
             token = kwargs['access_token']
-            unverified = decode(token, verify=False)
-            headers = get_unverified_header(token)
-            decoded = JWTCryptor(headers, unverified).decode_register(token)
+            decoded = decode(token, algorithms=['RS256'])
         except:
             raise exceptions.JWTDecodeError
 
